@@ -314,4 +314,100 @@ class StreamMsgType(enum.Enum):
                 return member
         raise exceptions._EnumParseError(code, cls)
 
+@enum.unique
+class Exchange(enum.Enum):
+    """Codes used to ID types of requests/responses."""
+
+    COMP = (0, "", "Comp")
+    NQEX = (1, "XNMS", "Nasdaq Exchange")
+    NQAD = (2, "XADF", "Nasdaq Alternative Display Facility")
+    NYSE = (3, "XNYS", "New York Stock Exchange")
+    AMEX = (4, "XASE", "American Stock Exchange")
+    CBOE = (5, "XCBO", "Chicago Board Options Exchange")
+    ISEX = (6, "XISX", "International Securities Exchange")
+    PACF = (7, "ARCX", "NYSE ARCA (Pacific)")
+    CINC = (8, "XCIS", "National Stock Exchange (Cincinnati)")
+    PHIL = (9, "XPHL", "Philidelphia Stock Exchange")
+    OPRA = (10, "OPRA", "Options Pricing Reporting Authority")
+    BOST = (11, "XBOS", "Boston Stock/Options Exchange")
+    NQNM = (12, "XNGS", "Nasdaq Global+Select Market (NMS)")
+    NQSC = (13, "XNCM", "Nasdaq Capital Market (SmallCap)")
+    NQBB = (14, "OOTC", "Nasdaq Bulletin Board")
+    NQPK = (15, "OOTC", "Nasdaq OTC")
+    NQAG = (16, "XADF", "Nasdaq Aggregate Quote")
+    CHIC = (17, "CXHI", "Chicago Stock Exchange")
+    TSE = (18, "XTSE", "Toronto Stock Exchange")
+    CDNX = (19, "XTSX", "Canadian Venture Exchange")
+    CME = (20, "XCME", "Chicago Mercantile Exchange")
+    NYBT = (21, "IMAG", "New York Board of Trade")
+    MRCY = (22, "MCRY", "ISE Mercury")
+    COMX = (23, "XCEC", "COMEX (division of NYMEX)")
+    CBOT = (24, "GLBX", "Chicago Board of Trade")
+    NYMX = (25, "XNYM", "New York Mercantile Exchange")
+    KCBT = (26, "XKBT", "Kansas City Board of Trade")
+    MGEX = (27, "XMGE", "Minneapolis Grain Exchange")
+    WCE = (28, "IFCA", "Winnipeg Commodity Exchange")
+    ONEC = (29, "XOCH", "OneChicago Exchange")
+    DOWJ = (30, "", "Dow Jones Indicies")
+    GEMI = (31, "GMNI", "ISE Gemini")
+    SIMX = (32, "XSES", "Singapore International Monetary Exchange")
+    FTSE = (33, "XLON", "London Stock Exchange")
+    EURX = (34, "XEUR", "Eurex")
+    ENXT = (35, "XAMS", "EuroNext")
+    DTN = (36, "", "Data Transmission Network")
+    LMT = (37, "XLME", "London Metals Exchange Matched Trades")
+    LME = (38, "XLME", "London Metals Exchange")
+    IPEX = (39, "IEPA", "Intercontinental Exchange (IPE)")
+    MX = (40, "XMOD", "Montreal Stock Exchange")
+    WSE = (41, "XTSX", "Winnipeg Stock Exchange")
+    C2 = (42, "C2OX", "CBOE C2 Option Exchange")
+    MIAX = (43, "XMIO", "Miami Exchange")
+    CLRP = (44, "XNYM", "NYMEX Clearport")
+    BARK = (45, "BARX", "Barclays")
+    TEN4 = (46, "", "TenFore")
+    NQBX = (47, "XBOS", "NASDAQ Boston")
+    HOTS = (48, "XEUR", "HotSpot Eurex US")
+    EUUS = (49, "XEUR", "Eurex US")
+    EUEU = (50, "XEUR", "Eurex EU")
+    ENCM = (51, "XEUC", "Euronext Commodities")
+    ENID = (52, "XEUE", "Euronext Index Derivatives")
+    ENIR = (53, "XEUI", "Euronext Interest Rates")
+    CFE = (54, "XCBF", "CBOE Futures Exchange")
+    PBOT = (55, "XPBT", "Philadelphia Board of Trade")
+    HWTB = (56, "XHAN", "Hannover WTB Exchange")
+    NQNX = (57, "FINN", "FINRA/NASDAQ Trade Reporting Facility")
+    BTRF = (58, "XADF", "BSE Trade Reporting Facility")
+    NTRF = (59, "FINY", "NYSE Trade Reporting Facility")
+    BATS = (60, "BATS", "BATS Trading")
+    NYLF = (61, "XNLI", "NYSE LIFFE metals contracts")
+    PINK = (62, "OTCM", "Pink Sheets")
+    BATY = (63, "BATY", "BATS Trading")
+    EDGE = (64, "EDGA", "Direct Edge")
+    EDGX = (65, "EDGX", "Direct Edge")
+    RUSL = (66, "", "Russell Indexes")
+    CMEX = (67, "XIOM", "CME Indexes")
+    IEX = (68, "IEXG", "Investors Exchange")
+    TBA_69 = (69, "", "TBA Exchange 69")
+    TBA_70 = (70, "", "TBA Exchange 70")
+    TBA_71 = (71, "", "TBA Exchange 71")
+    TBA_72 = (72, "", "TBA Exchange 72")
+    TBA_73 = (73, "", "TBA Exchange 73")
+    TBA_74 = (74, "", "TBA Exchange 74")
+    TBA_75 = (75, "", "TBA Exchange 75")
+    TBA_76 = (76, "", "TBA Exchange 76")
+    TBA_77 = (77, "", "TBA Exchange 77")
+    TBA_78 = (78, "", "TBA Exchange 78")
+    TBA_79 = (79, "", "TBA Exchange 79")
+    @classmethod
+    def from_code(cls, code: int) -> MessageType:
+        """Create a MessageType by its associated code.
+
+        :raises EnumParseError: If the code does not match a MessageType
+        """
+        for member in cls:
+            if code == member.value[0]:
+                return member
+        raise exceptions._EnumParseError(code, cls)
+
+
 
